@@ -1,7 +1,7 @@
 
-__version__ = '0.0.1'
+__version__ = '0.0.2'
 
-from .ferry import *
+from ferry import *
 from .meta import *
 from .nodes import *
 from .terrors import *
